@@ -20,8 +20,10 @@
 
 #include <cstdio>
 #include <cerrno>
+#include <memory>
 #include <unistd.h>
 #include <sstream>
+#include <string>
 #include <sys/stat.h>
 
 #include "common.h"
@@ -33,13 +35,13 @@
 //------------------------------------------------
 // Symbols
 //------------------------------------------------
-static const int CHECK_CACHEFILE_PART_SIZE = 1024 * 16;    // Buffer size in PageList::CheckZeroAreaInFile()
+static constexpr int CHECK_CACHEFILE_PART_SIZE = 1024 * 16;    // Buffer size in PageList::CheckZeroAreaInFile()
 
 //------------------------------------------------
 // fdpage_list_t utility
 //------------------------------------------------
 // Inline function for repeated processing
-inline void raw_add_compress_fdpage_list(fdpage_list_t& pagelist, const fdpage& orgpage, bool ignore_load, bool ignore_modify, bool default_load, bool default_modify)
+static inline void raw_add_compress_fdpage_list(fdpage_list_t& pagelist, const fdpage& orgpage, bool ignore_load, bool ignore_modify, bool default_load, bool default_modify)
 {
     if(0 < orgpage.bytes){
         // [NOTE]
@@ -72,9 +74,9 @@ static void raw_compress_fdpage_list(const fdpage_list_t& pages, fdpage_list_t&
 {
     compressed_pages.clear();
 
-    fdpage*                 lastpage = NULL;
+    fdpage*                 lastpage = nullptr;
     fdpage_list_t::iterator add_iter;
-    for(fdpage_list_t::const_iterator iter = pages.begin(); iter != pages.end(); ++iter){
+    for(auto iter = pages.cbegin(); iter != pages.cend(); ++iter){
         if(0 == iter->bytes){
             continue;
         }
@@ -138,7 +140,7 @@ static void compress_fdpage_list(const fdpage_list_t& pages, fdpage_list_t& comp
 static fdpage_list_t parse_partsize_fdpage_list(const fdpage_list_t& pages, off_t max_partsize)
 {
     fdpage_list_t parsed_pages;
-    for(fdpage_list_t::const_iterator iter = pages.begin(); iter != pages.end(); ++iter){
+    for(auto iter = pages.cbegin(); iter != pages.cend(); ++iter){
         if(iter->modified){
             // modified page
             fdpage tmppage = *iter;
@@ -232,7 +234,7 @@ bool PageList::GetSparseFilePages(int fd, size_t file_size, fdpage_list_t& spars
 //
 bool PageList::CheckZeroAreaInFile(int fd, off_t start, size_t bytes)
 {
-    char* readbuff = new char[CHECK_CACHEFILE_PART_SIZE];
+    auto readbuff = std::make_unique<char[]>(CHECK_CACHEFILE_PART_SIZE);
 
     for(size_t comp_bytes = 0, check_bytes = 0; comp_bytes < bytes; comp_bytes += check_bytes){
         if(CHECK_CACHEFILE_PART_SIZE < (bytes - comp_bytes)){
@@ -242,7 +244,7 @@ bool PageList::CheckZeroAreaInFile(int fd, off_t start, size_t bytes)
         }
         bool    found_bad_data = false;
         ssize_t read_bytes;
-        if(-1 == (read_bytes = pread(fd, readbuff, check_bytes, (start + comp_bytes)))){
+        if(-1 == (read_bytes = pread(fd, readbuff.get(), check_bytes, (start + comp_bytes)))){
             S3FS_PRN_ERR("Something error is occurred in reading %zu bytes at %lld from file(physical_fd=%d).", check_bytes, static_cast<long long int>(start + comp_bytes), fd);
             found_bad_data = true;
         }else{
@@ -256,11 +258,9 @@ bool PageList::CheckZeroAreaInFile(int fd, off_t start, size_t bytes)
             }
         }
         if(found_bad_data){
-            delete[] readbuff;
             return false;
         }
     }
-    delete[] readbuff;
     return true;
 }
 
@@ -271,7 +271,7 @@ bool PageList::CheckZeroAreaInFile(int fd, off_t start, size_t bytes)
 // checkpage:    This is one state of the cache file, it is loaded from the stats file.
 // sparse_list:  This is a list of the results of directly checking the cache file status(HOLE/DATA).
 //               In the HOLE area, the "loaded" flag of fdpage is false. The DATA area has it set to true.
-// fd:           opened file discriptor to target cache file.
+// fd:           opened file descriptor to target cache file.
 //
 bool PageList::CheckAreaInSparseFile(const struct fdpage& checkpage, const fdpage_list_t& sparse_list, int fd, fdpage_list_t& err_area_list, fdpage_list_t& warn_area_list)
 {
@@ -289,7 +289,7 @@ bool PageList::CheckAreaInSparseFile(const struct fdpage& checkpage, const fdpag
     //
     bool result = true;
 
-    for(fdpage_list_t::const_iterator iter = sparse_list.begin(); iter != sparse_list.end(); ++iter){
+    for(auto iter = sparse_list.cbegin(); iter != sparse_list.cend(); ++iter){
         off_t check_start = 0;
         off_t check_bytes = 0;
         if((iter->offset + iter->bytes) <= checkpage.offset){
@@ -354,19 +354,11 @@ void PageList::FreeList(fdpage_list_t& list)
     list.clear();
 }
 
-PageList::PageList(off_t size, bool is_loaded, bool is_modified, bool shrinked) : is_shrink(shrinked)
+PageList::PageList(off_t size, bool is_loaded, bool is_modified, bool shrunk) : is_shrink(shrunk)
 {
     Init(size, is_loaded, is_modified);
 }
 
-PageList::PageList(const PageList& other)
-{
-    for(fdpage_list_t::const_iterator iter = other.pages.begin(); iter != other.pages.end(); ++iter){
-        pages.push_back(*iter);
-    }
-    is_shrink = other.is_shrink;
-}
-
 PageList::~PageList()
 {
     Clear();
@@ -393,14 +385,14 @@ off_t PageList::Size() const
     if(pages.empty()){
         return 0;
     }
-    fdpage_list_t::const_reverse_iterator riter = pages.rbegin();
+    auto riter = pages.rbegin();
     return riter->next();
 }
 
 bool PageList::Compress()
 {
-    fdpage* lastpage = NULL;
-    for(fdpage_list_t::iterator iter = pages.begin(); iter != pages.end(); ){
+    fdpage* lastpage = nullptr;
+    for(auto iter = pages.begin(); iter != pages.end(); ){
         if(!lastpage){
             // First item
             lastpage = &(*iter);
@@ -436,7 +428,7 @@ bool PageList::Compress()
 
 bool PageList::Parse(off_t new_pos)
 {
-    for(fdpage_list_t::iterator iter = pages.begin(); iter != pages.end(); ++iter){
+    for(auto iter = pages.begin(); iter != pages.end(); ++iter){
         if(new_pos == iter->offset){
             // nothing to do
             return true;
@@ -471,7 +463,7 @@ bool PageList::Resize(off_t size, bool is_loaded, bool is_modified)
 
     }else if(size < total){
         // cut area
-        for(fdpage_list_t::iterator iter = pages.begin(); iter != pages.end(); ){
+        for(auto iter = pages.begin(); iter != pages.end(); ){
             if(iter->next() <= size){
                 ++iter;
             }else{
@@ -494,7 +486,7 @@ bool PageList::Resize(off_t size, bool is_loaded, bool is_modified)
 
 bool PageList::IsPageLoaded(off_t start, off_t size) const
 {
-    for(fdpage_list_t::const_iterator iter = pages.begin(); iter != pages.end(); ++iter){
+    for(auto iter = pages.cbegin(); iter != pages.cend(); ++iter){
         if(iter->end() < start){
             continue;
         }
@@ -511,8 +503,8 @@ bool PageList::IsPageLoaded(off_t start, off_t size) const
 bool PageList::SetPageLoadedStatus(off_t start, off_t size, PageList::page_status pstatus, bool is_compress)
 {
     off_t now_size    = Size();
-    bool  is_loaded   = (PAGE_LOAD_MODIFIED == pstatus || PAGE_LOADED == pstatus);
-    bool  is_modified = (PAGE_LOAD_MODIFIED == pstatus || PAGE_MODIFIED == pstatus);
+    bool  is_loaded   = (page_status::LOAD_MODIFIED == pstatus || page_status::LOADED == pstatus);
+    bool  is_modified = (page_status::LOAD_MODIFIED == pstatus || page_status::MODIFIED == pstatus);
 
     if(now_size <= start){
         if(now_size < start){
@@ -534,7 +526,7 @@ bool PageList::SetPageLoadedStatus(off_t start, off_t size, PageList::page_statu
         Parse(start + size);
 
         // set loaded flag
-        for(fdpage_list_t::iterator iter = pages.begin(); iter != pages.end(); ++iter){
+        for(auto iter = pages.begin(); iter != pages.end(); ++iter){
             if(iter->end() < start){
                 continue;
             }else if(start + size <= iter->offset){
@@ -551,7 +543,7 @@ bool PageList::SetPageLoadedStatus(off_t start, off_t size, PageList::page_statu
 
 bool PageList::FindUnloadedPage(off_t start, off_t& resstart, off_t& ressize) const
 {
-    for(fdpage_list_t::const_iterator iter = pages.begin(); iter != pages.end(); ++iter){
+    for(auto iter = pages.cbegin(); iter != pages.cend(); ++iter){
         if(start <= iter->end()){
             if(!iter->loaded && !iter->modified){     // Do not load unloaded and modified areas
                 resstart = iter->offset;
@@ -577,7 +569,7 @@ off_t PageList::GetTotalUnloadedPageSize(off_t start, off_t size, off_t limit_si
     }
     off_t next     = start + size;
     off_t restsize = 0;
-    for(fdpage_list_t::const_iterator iter = pages.begin(); iter != pages.end(); ++iter){
+    for(auto iter = pages.cbegin(); iter != pages.cend(); ++iter){
         if(iter->next() <= start){
             continue;
         }
@@ -618,7 +610,7 @@ size_t PageList::GetUnloadedPages(fdpage_list_t& unloaded_list, off_t start, off
     }
     off_t next = start + size;
 
-    for(fdpage_list_t::const_iterator iter = pages.begin(); iter != pages.end(); ++iter){
+    for(auto iter = pages.cbegin(); iter != pages.cend(); ++iter){
         if(iter->next() <= start){
             continue;
         }
@@ -635,7 +627,7 @@ size_t PageList::GetUnloadedPages(fdpage_list_t& unloaded_list, off_t start, off
         off_t page_size  = page_next - page_start;
 
         // add list
-        fdpage_list_t::reverse_iterator riter = unloaded_list.rbegin();
+        auto riter = unloaded_list.rbegin();
         if(riter != unloaded_list.rend() && riter->next() == page_start){
             // merge to before page
             riter->bytes += page_size;
@@ -657,9 +649,7 @@ size_t PageList::GetUnloadedPages(fdpage_list_t& unloaded_list, off_t start, off
 bool PageList::GetPageListsForMultipartUpload(fdpage_list_t& dlpages, fdpage_list_t& mixuppages, off_t max_partsize)
 {
     // compress before this processing
-    if(!Compress()){
-        return false;
-    }
+    Compress();         // always true
 
     // make a list by modified flag
     fdpage_list_t modified_pages;
@@ -668,7 +658,7 @@ bool PageList::GetPageListsForMultipartUpload(fdpage_list_t& dlpages, fdpage_lis
     compress_fdpage_list_ignore_load(pages, modified_pages, false);
 
     fdpage        prev_page;
-    for(fdpage_list_t::const_iterator iter = modified_pages.begin(); iter != modified_pages.end(); ++iter){
+    for(auto iter = modified_pages.cbegin(); iter != modified_pages.cend(); ++iter){
         if(iter->modified){
             // current is modified area
             if(!prev_page.modified){
@@ -760,14 +750,12 @@ bool PageList::GetPageListsForMultipartUpload(fdpage_list_t& dlpages, fdpage_lis
 bool PageList::GetNoDataPageLists(fdpage_list_t& nodata_pages, off_t start, size_t size)
 {
     // compress before this processing
-    if(!Compress()){
-        return false;
-    }
+    Compress();         // always true
 
     // extract areas without data
     fdpage_list_t tmp_pagelist;
     off_t         stop_pos = (0L == size ? -1 : (start + size));
-    for(fdpage_list_t::const_iterator iter = pages.begin(); iter != pages.end(); ++iter){
+    for(auto iter = pages.cbegin(); iter != pages.cend(); ++iter){
         if((iter->offset + iter->bytes) < start){
             continue;
         }
@@ -799,7 +787,7 @@ bool PageList::GetNoDataPageLists(fdpage_list_t& nodata_pages, off_t start, size
 off_t PageList::BytesModified() const
 {
     off_t total = 0;
-    for(fdpage_list_t::const_iterator iter = pages.begin(); iter != pages.end(); ++iter){
+    for(auto iter = pages.cbegin(); iter != pages.cend(); ++iter){
         if(iter->modified){
             total += iter->bytes;
         }
@@ -812,7 +800,7 @@ bool PageList::IsModified() const
     if(is_shrink){
         return true;
     }
-    for(fdpage_list_t::const_iterator iter = pages.begin(); iter != pages.end(); ++iter){
+    for(auto iter = pages.cbegin(); iter != pages.cend(); ++iter){
         if(iter->modified){
             return true;
         }
@@ -824,7 +812,7 @@ bool PageList::ClearAllModified()
 {
     is_shrink = false;
 
-    for(fdpage_list_t::iterator iter = pages.begin(); iter != pages.end(); ++iter){
+    for(auto iter = pages.begin(); iter != pages.end(); ++iter){
         if(iter->modified){
             iter->modified = false;
         }
@@ -832,154 +820,151 @@ bool PageList::ClearAllModified()
     return Compress();
 }
 
-bool PageList::Serialize(CacheFileStat& file, bool is_output, ino_t inode)
+bool PageList::Serialize(const CacheFileStat& file, ino_t inode) const
+{
+    // make contents
+    std::ostringstream ssall;
+    ssall << inode << ":" << Size();
+
+    for(auto iter = pages.cbegin(); iter != pages.cend(); ++iter){
+        ssall << "\n" << iter->offset << ":" << iter->bytes << ":" << (iter->loaded ? "1" : "0") << ":" << (iter->modified ? "1" : "0");
+    }
+    std::string strall = ssall.str();
+
+    // over write
+    if(!file.OverWriteFile(strall)){
+        return false;
+    }
+    return true;
+}
+
+bool PageList::Deserialize(CacheFileStat& file, ino_t inode)
 {
     if(!file.Open()){
         return false;
     }
-    if(is_output){
-        //
-        // put to file
-        //
-        std::ostringstream ssall;
-        ssall << inode << ":" << Size();
 
-        for(fdpage_list_t::iterator iter = pages.begin(); iter != pages.end(); ++iter){
-            ssall << "\n" << iter->offset << ":" << iter->bytes << ":" << (iter->loaded ? "1" : "0") << ":" << (iter->modified ? "1" : "0");
-        }
+    //
+    // loading from file
+    //
+    struct stat st{};
+    if(-1 == fstat(file.GetFd(), &st)){
+        S3FS_PRN_ERR("fstat is failed. errno(%d)", errno);
+        return false;
+    }
+    if(0 >= st.st_size){
+        // nothing
+        Init(0, false, false);
+        return true;
+    }
+    auto ptmp = std::make_unique<char[]>(st.st_size + 1);
+    ssize_t result;
+    // read from file
+    if(0 >= (result = pread(file.GetFd(), ptmp.get(), st.st_size, 0))){
+        S3FS_PRN_ERR("failed to read stats(%d)", errno);
+        return false;
+    }
+    ptmp[result] = '\0';
+    std::string        oneline;
+    std::istringstream ssall(ptmp.get());
 
-        if(-1 == ftruncate(file.GetFd(), 0)){
-            S3FS_PRN_ERR("failed to truncate file(to 0) for stats(%d)", errno);
-            return false;
-        }
-        std::string strall = ssall.str();
-        if(0 >= pwrite(file.GetFd(), strall.c_str(), strall.length(), 0)){
-            S3FS_PRN_ERR("failed to write stats(%d)", errno);
-            return false;
-        }
+    // loaded
+    Clear();
 
+    // load head line(for size and inode)
+    off_t total;
+    ino_t cache_inode;                  // if this value is 0, it means old format.
+    if(!getline(ssall, oneline, '\n')){
+        S3FS_PRN_ERR("failed to parse stats.");
+        return false;
     }else{
-        //
-        // loading from file
-        //
-        struct stat st;
-        memset(&st, 0, sizeof(struct stat));
-        if(-1 == fstat(file.GetFd(), &st)){
-            S3FS_PRN_ERR("fstat is failed. errno(%d)", errno);
-            return false;
-        }
-        if(0 >= st.st_size){
-          // nothing
-            Init(0, false, false);
-            return true;
-        }
-        char* ptmp = new char[st.st_size + 1];
-        ssize_t result;
-        // read from file
-        if(0 >= (result = pread(file.GetFd(), ptmp, st.st_size, 0))){
-            S3FS_PRN_ERR("failed to read stats(%d)", errno);
-            delete[] ptmp;
-            return false;
-        }
-        ptmp[result] = '\0';
-        std::string        oneline;
-        std::istringstream ssall(ptmp);
-    
-        // loaded
-        Clear();
-    
-        // load head line(for size and inode)
-        off_t total;
-        ino_t cache_inode;                  // if this value is 0, it means old format.
-        if(!getline(ssall, oneline, '\n')){
+        std::istringstream sshead(oneline);
+        std::string        strhead1;
+        std::string        strhead2;
+
+        // get first part in head line.
+        if(!getline(sshead, strhead1, ':')){
             S3FS_PRN_ERR("failed to parse stats.");
-            delete[] ptmp;
             return false;
+        }
+        // get second part in head line.
+        if(!getline(sshead, strhead2, ':')){
+            // old head format is "<size>\n"
+            total       = cvt_strtoofft(strhead1.c_str(), /* base= */10);
+            cache_inode = 0;
         }else{
-            std::istringstream sshead(oneline);
-            std::string        strhead1;
-            std::string        strhead2;
-    
-            // get first part in head line.
-            if(!getline(sshead, strhead1, ':')){
-                S3FS_PRN_ERR("failed to parse stats.");
-                delete[] ptmp;
+            // current head format is "<inode>:<size>\n"
+            total       = cvt_strtoofft(strhead2.c_str(), /* base= */10);
+            cache_inode = static_cast<ino_t>(cvt_strtoofft(strhead1.c_str(), /* base= */10));
+            if(0 == cache_inode){
+                S3FS_PRN_ERR("wrong inode number in parsed cache stats.");
                 return false;
             }
-            // get second part in head line.
-            if(!getline(sshead, strhead2, ':')){
-                // old head format is "<size>\n"
-                total       = cvt_strtoofft(strhead1.c_str(), /* base= */10);
-                cache_inode = 0;
-            }else{
-                // current head format is "<inode>:<size>\n"
-                total       = cvt_strtoofft(strhead2.c_str(), /* base= */10);
-                cache_inode = static_cast<ino_t>(cvt_strtoofft(strhead1.c_str(), /* base= */10));
-                if(0 == cache_inode){
-                    S3FS_PRN_ERR("wrong inode number in parsed cache stats.");
-                    delete[] ptmp;
-                    return false;
-                }
-            }
-        }
-        // check inode number
-        if(0 != cache_inode && cache_inode != inode){
-            S3FS_PRN_ERR("differ inode and inode number in parsed cache stats.");
-            delete[] ptmp;
-            return false;
-        }
-    
-        // load each part
-        bool is_err = false;
-        while(getline(ssall, oneline, '\n')){
-            std::string        part;
-            std::istringstream ssparts(oneline);
-            // offset
-            if(!getline(ssparts, part, ':')){
-                is_err = true;
-                break;
-            }
-            off_t offset = cvt_strtoofft(part.c_str(), /* base= */10);
-            // size
-            if(!getline(ssparts, part, ':')){
-                is_err = true;
-                break;
-            }
-            off_t size = cvt_strtoofft(part.c_str(), /* base= */10);
-            // loaded
-            if(!getline(ssparts, part, ':')){
-                is_err = true;
-                break;
-            }
-            bool is_loaded = (1 == cvt_strtoofft(part.c_str(), /* base= */10) ? true : false);
-            bool is_modified;
-            if(!getline(ssparts, part, ':')){
-                is_modified = false;        // old version does not have this part.
-            }else{
-                is_modified = (1 == cvt_strtoofft(part.c_str(), /* base= */10) ? true : false);
-            }
-            // add new area
-            PageList::page_status pstatus = 
-              ( is_loaded && is_modified  ? PageList::PAGE_LOAD_MODIFIED : 
-                !is_loaded && is_modified ? PageList::PAGE_MODIFIED      : 
-                is_loaded && !is_modified ? PageList::PAGE_LOADED        : PageList::PAGE_NOT_LOAD_MODIFIED );
-
-            SetPageLoadedStatus(offset, size, pstatus);
-        }
-        delete[] ptmp;
-        if(is_err){
-            S3FS_PRN_ERR("failed to parse stats.");
-            Clear();
-            return false;
-        }
-  
-        // check size
-        if(total != Size()){
-            S3FS_PRN_ERR("different size(%lld - %lld).", static_cast<long long int>(total), static_cast<long long int>(Size()));
-            Clear();
-            return false;
         }
     }
+    // check inode number
+    if(0 != cache_inode && cache_inode != inode){
+        S3FS_PRN_ERR("differ inode and inode number in parsed cache stats.");
+        return false;
+    }
+
+    // load each part
+    bool is_err = false;
+    while(getline(ssall, oneline, '\n')){
+        std::string        part;
+        std::istringstream ssparts(oneline);
+        // offset
+        if(!getline(ssparts, part, ':')){
+            is_err = true;
+            break;
+        }
+        off_t offset = cvt_strtoofft(part.c_str(), /* base= */10);
+        // size
+        if(!getline(ssparts, part, ':')){
+            is_err = true;
+            break;
+        }
+        off_t size = cvt_strtoofft(part.c_str(), /* base= */10);
+        // loaded
+        if(!getline(ssparts, part, ':')){
+            is_err = true;
+            break;
+        }
+        bool is_loaded = (1 == cvt_strtoofft(part.c_str(), /* base= */10) ? true : false);
+        bool is_modified;
+        if(!getline(ssparts, part, ':')){
+            is_modified = false;        // old version does not have this part.
+        }else{
+            is_modified = (1 == cvt_strtoofft(part.c_str(), /* base= */10) ? true : false);
+        }
+        // add new area
+        PageList::page_status pstatus = PageList::page_status::NOT_LOAD_MODIFIED;
+        if(is_loaded){
+            if(is_modified){
+                pstatus = PageList::page_status::LOAD_MODIFIED;
+            }else{
+                pstatus = PageList::page_status::LOADED;
+            }
+        }else{
+            if(is_modified){
+                pstatus = PageList::page_status::MODIFIED;
+            }
+        }
+        SetPageLoadedStatus(offset, size, pstatus);
+    }
+    if(is_err){
+        S3FS_PRN_ERR("failed to parse stats.");
+        Clear();
+        return false;
+    }
+
+    // check size
+    if(total != Size()){
+        S3FS_PRN_ERR("different size(%lld - %lld).", static_cast<long long int>(total), static_cast<long long int>(Size()));
+        Clear();
+        return false;
+    }
+
     return true;
 }
 
@@ -987,8 +972,8 @@ void PageList::Dump() const
 {
     int cnt = 0;
 
-    S3FS_PRN_DBG("pages (shrinked=%s) = {", (is_shrink ? "yes" : "no"));
-    for(fdpage_list_t::const_iterator iter = pages.begin(); iter != pages.end(); ++iter, ++cnt){
+    S3FS_PRN_DBG("pages (shrunk=%s) = {", (is_shrink ? "yes" : "no"));
+    for(auto iter = pages.cbegin(); iter != pages.cend(); ++iter, ++cnt){
         S3FS_PRN_DBG("  [%08d] -> {%014lld - %014lld : %s / %s}", cnt, static_cast<long long int>(iter->offset), static_cast<long long int>(iter->bytes), iter->loaded ? "loaded" : "unloaded", iter->modified ? "modified" : "not modified");
     }
     S3FS_PRN_DBG("}");
@@ -1004,7 +989,7 @@ void PageList::Dump() const
 // If it is a bad area in the previous case, it will be reported as an error.
 // If the latter case does not match, it will be reported as a warning.
 // 
-bool PageList::CompareSparseFile(int fd, size_t file_size, fdpage_list_t& err_area_list, fdpage_list_t& warn_area_list)
+bool PageList::CompareSparseFile(int fd, size_t file_size, fdpage_list_t& err_area_list, fdpage_list_t& warn_area_list) const
 {
     err_area_list.clear();
     warn_area_list.clear();
@@ -1029,7 +1014,7 @@ bool PageList::CompareSparseFile(int fd, size_t file_size, fdpage_list_t& err_ar
 
     // Compare each pages and sparse_list
     bool result = true;
-    for(fdpage_list_t::const_iterator iter = pages.begin(); iter != pages.end(); ++iter){
+    for(auto iter = pages.cbegin(); iter != pages.cend(); ++iter){
         if(!PageList::CheckAreaInSparseFile(*iter, sparse_list, fd, err_area_list, warn_area_list)){
             result = false;
         }
